CedarBackup3.extend — cedar-backup3 3.10.0 documentation

# CedarBackup3.extend

Official Cedar Backup Extensions

This package provides official Cedar Backup extensions. These are Cedar Backup actions that are not part of the “standard” set of Cedar Backup actions, but are officially supported along with Cedar Backup.

author:

  Kenneth J. Pronovici <pronovic@ieee.org>

## Submodules

- CedarBackup3.extend.amazons3
- CedarBackup3.extend.capacity
- CedarBackup3.extend.encrypt
- CedarBackup3.extend.mbox
- CedarBackup3.extend.mysql
- CedarBackup3.extend.postgresql
- CedarBackup3.extend.split
- CedarBackup3.extend.subversion
- CedarBackup3.extend.sysinfo